@@ -1,5 +1,5 @@
+from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import Resource
-from ocp_resources.utils import TimeoutExpiredError, nudge_delete
 
 
 class Project(Resource):
@@ -13,6 +13,9 @@ class Project(Resource):
     class Status(Resource.Status):
         ACTIVE = "Active"
 
+    def clean_up(self):
+        Project(name=self.name).delete(wait=True)
+
 
 class ProjectRequest(Resource):
     """
@@ -25,11 +28,23 @@ class ProjectRequest(Resource):
 
     def __init__(
         self,
-        name,
+        name=None,
         client=None,
         teardown=True,
+        timeout=TIMEOUT_4MINUTES,
+        yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
-        super().__init__(name=name, client=client, teardown=teardown)
+        super().__init__(
+            name=name,
+            client=client,
+            teardown=teardown,
+            timeout=timeout,
+            yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
+        )
 
     def clean_up(self):
         Project(name=self.name).delete(wait=True)
@@ -42,7 +57,4 @@ class ProjectRequest(Resource):
             timeout (int): Time to wait for the resource.
 
         """
-        try:
-            super().client_wait_deleted(timeout=timeout)
-        except TimeoutExpiredError:
-            nudge_delete(name=self.name)
+        super().client_wait_deleted(timeout=timeout)
