@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 
-
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.resource import TIMEOUT, NamespacedResource
+from ocp_resources.logger import get_logger
+from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine_instance import VirtualMachineInstance
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class VirtualMachine(NamespacedResource):
     """
     Virtual Machine object, inherited from Resource.
@@ -38,6 +41,8 @@ class VirtualMachine(NamespacedResource):
         teardown=True,
         privileged_client=None,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -46,6 +51,8 @@ class VirtualMachine(NamespacedResource):
             teardown=teardown,
             privileged_client=privileged_client,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.body = body
 
@@ -71,24 +78,24 @@ class VirtualMachine(NamespacedResource):
         res["spec"] = body_spec or {"template": {"spec": {}}}
         return res
 
-    def start(self, timeout=TIMEOUT, wait=False):
+    def start(self, timeout=TIMEOUT_4MINUTES, wait=False):
         self.api_request(method="PUT", action="start")
         if wait:
             return self.wait_for_status(timeout=timeout, status=True)
 
-    def restart(self, timeout=TIMEOUT, wait=False):
+    def restart(self, timeout=TIMEOUT_4MINUTES, wait=False):
         self.api_request(method="PUT", action="restart")
         if wait:
             self.vmi.virt_launcher_pod.wait_deleted()
             return self.vmi.wait_until_running(timeout=timeout, stop_status="dummy")
 
-    def stop(self, timeout=TIMEOUT, wait=False):
+    def stop(self, timeout=TIMEOUT_4MINUTES, wait=False):
         self.api_request(method="PUT", action="stop")
         if wait:
             self.wait_for_status(timeout=timeout, status=None)
             return self.vmi.wait_deleted()
 
-    def wait_for_status(self, status, timeout=TIMEOUT, sleep=1):
+    def wait_for_status(self, status, timeout=TIMEOUT_4MINUTES, sleep=1):
         """
         Wait for resource to be in status
 
@@ -99,7 +106,7 @@ class VirtualMachine(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
+        LOGGER.info(
             f"Wait for {self.kind} {self.name} status to be {'ready' if status == True else status}"
         )
         samples = TimeoutSampler(
@@ -153,14 +160,3 @@ class VirtualMachine(NamespacedResource):
             VM printableStatus if VM.status.printableStatus else None
         """
         return self.instance.get("status", {}).get("printableStatus")
-
-    def wait_for_status_none(self, status, timeout=TIMEOUT_4MINUTES):
-        self.logger.info(f"Wait for {self.kind} {self.name} status {status} to be None")
-        for sample in TimeoutSampler(
-            wait_timeout=timeout,
-            sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=lambda: self.instance.get("status", {}).get(status),
-        ):
-            if sample is None:
-                return
